' --------------------------------------------------------------
'
' Licensed Materials - Property of IBM
' "Restricted Materials of IBM"
' 5746-SM2
'   Copyright IBM Corp. 1999, 2003 All Rights Reserved.
' US Government Users Restricted Rights - Use, duplication or
' disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
'
' --------------------------------------------------------------
Option Strict Off
Option Explicit On 
Imports System.Xml
Module Module1
	' --------------------------------------------------------------
    'Sample API application
    '
    ' NavigatorTree is a sample application that exercises the eRecords
    ' Engine API. The NavigatorTree displays the file plan of an eRecordsEngine
    ' System using the VB "TreeView  Control" common control 	'
    ' This application requires:
    '   - VB NET runtime
    '   - xml parser
    '   - IBM Records Manager Engine
    '   - client proxy - NetWebServicesClientProxy
    '   - header handler - NetSoapHeaderHandler
    ' This application has being configured to use the web services API
	'
	' This application demonstrates the use of an "optimized" tree view control. When navigating
	' through the file plan, each branch that is expanded is stored in the tree view  control
	' as it is expanded. The tree view control requires only as much RAM as the nodes that you
	' have expanded. If you close a branch the file plan components remain in memory for quick
	' display the next time.
	'
	' When a new node is expanded, all of it's children are read in and added to the tree view
	' control. If any of the children themselves have children, then a [+] sign is rendered on that
	' branch to indicate to the user that the branch can be expanded.
	'
	' This was acccomplished by tricking the tree view control into displaying the [+] sign by adding
	' a dummy node beneath the parent. The tree view control automatically displays a [+]
	' sign when their are subnodes (in the tree). Once the branch is expanded for the first time, the
	' dummy node is deleted and replaced with the legitimate children.
	'
	
	' ---------------------------------------------------------------------------------
	
	
	Public Const LISTVIEW_MODE0 As String = "View Large Icons"
	Public Const LISTVIEW_MODE1 As String = "View Small Icons"
	Public Const LISTVIEW_MODE2 As String = "View List"
	Public Const LISTVIEW_MODE3 As String = "View Details"
	
	' Global main form displaying tree control navigator
    Public fMainForm As New frmMain()
	
	' Global variables
    'Public oClientController As MSSOAPLib30.SoapClient30
    Public oNetClientController As NetWebServicesClientProxy.ibm.com.ClientControllerEJBService
    Public strClientControllerKey As String
    Public strFilePlanDesignControllerKey As String
    Private strFilePlanComponentControllerKey As String
    Public oNetFilePlanComponentController As NetWebServicesClientProxy.ibm.com.FilePlanComponentControllerEJBService
	Public gstrTitle As String ' main form title
	Public gstrUserName As String ' user login name for eRecordsEngine
	Public gstrAlias As String ' database alias
	Public gstrPassword As String ' user password for eRecordsEngine
    Public gstrWSDLLocation As String ' WSDL file location (http://... )
    Public gstrURL As String ' server URL
    Public oNetHeaderHandler as NetSoapHeaderHandler.SoapHeaderHandler 
	Public gstrLoaded As String ' T if branch already loaded into tree. F if not
	Public gstrCompType As String ' V - view, F - for FPC, X - dummy node
	Public glID As Integer ' ID of view or FPC
	Public gstrTag As String ' Tag value for Node. Consists of strLoaded & strCompType & ID. stored with each node loaded into tree
	Public glViewID As Integer ' view id of currently expanded branch.
	
    'Public objHeaderHandler As SoapHeaderHandler.clsHeaderHandler
	
    Private mNode As TreeNode ' Module-level Node variable.
	
	' used to format the "tag" string stored in a node
	Public Sub SetTag(ByRef strTag As String, ByVal strLoaded As String, ByVal strCompType As String, ByVal lID As Integer)
		' e.g.    "TV29" for True, View, id 29
		
		strTag = strLoaded & strCompType & CStr(lID)
		
	End Sub
	
	' used to fetch the "tag" string stored in a node structure and deconstruct the components for
	' easier manipulation
	Public Sub GetTag(ByVal strTag As String, ByRef strLoaded As String, ByRef strCompType As String, ByRef lID As Integer)
		strLoaded = Left(strTag, 1)
		strCompType = Mid(strTag, 2, 1)
		lID = CInt(Mid(strTag, 3))
		
	End Sub
	
    ' Draw the initial tree consisting of all hierarchical VIEWS
    Public Function getFilePlanComponentControllerKey() As String
        If strFilePlanComponentControllerKey = "" Then
            oNetHeaderHandler.EJBKey = strClientControllerKey
            oNetClientController.headerValue = oNetHeaderHandler
            strFilePlanComponentControllerKey = oNetClientController.getFilePlanComponentControllerAsString()
        End If
        getFilePlanComponentControllerKey = strFilePlanComponentControllerKey
    End Function
    Public Sub LoadViews()

        Dim objXML As New XmlDocument()
        Dim objElement As XmlElement
        Dim i As Short
        Dim strTemp As String
        Dim strXML As String
        Dim lChildCount As Integer

        On Error GoTo errhandler

        oNetClientController = New NetWebServicesClientProxy.ibm.com.ClientControllerEJBService()
        oNetClientController.Url = gstrURL
        oNetHeaderHandler.EJBKey = strClientControllerKey
        oNetClientController.headerValue = oNetHeaderHandler
        strFilePlanDesignControllerKey = oNetClientController.getFilePlanDesignControllerAsString()

        Dim oNetFilePlanDesignController As New NetWebServicesClientProxy.ibm.com.FilePlanDesignControllerEJBService()
        oNetFilePlanDesignController.Url = gstrURL
        oNetHeaderHandler.EJBKey = strFilePlanDesignControllerKey
        oNetFilePlanDesignController.headerValue = oNetHeaderHandler
        strXML = oNetFilePlanDesignController.getFilePlanViewList(True)

        objXML.LoadXml(strXML)

        For Each objElement In objXML.ChildNodes(1).ChildNodes

            glID = CInt(objElement.GetAttribute("FlPlnViewID"))
            strTemp = "V" & CStr(glID)

            mNode = fMainForm.TreeView1.Nodes(0).Nodes.Add(objElement.GetAttribute("FlPlnViewNm"))
            SetTag(gstrTag, "F", "V", glID)
            mNode.Tag = gstrTag

        Next objElement
        System.Windows.Forms.Cursor.Current = System.Windows.Forms.Cursors.Default

        Exit Sub

errhandler:
        MsgBox(Err.Description)


    End Sub


    ' Main program
    ' Get a list of database aliases
    ' prompt for login information
    ' login and get the session id
    ' load the views into the tree view control
    ' display the tree view control

    Public Sub Main()
        Dim fLogin As New frmLogin()
        Dim oDatabase As Object
        Dim objXML As New XmlDocument()
        Dim objElement As XmlElement
        Dim strAliasName As String
        Dim strXML As String
        Dim strKey As String

        On Error GoTo errhandler

        ' Set up alias list
        System.Windows.Forms.Cursor.Current = System.Windows.Forms.Cursors.WaitCursor
        On Error Resume Next

        fLogin.LoginSucceeded = False

        fLogin.ShowDialog()
        If Not fLogin.LoginSucceeded Then
            'Login Failed so exit app
            End
        End If
        gstrUserName = fLogin.txtUserName.Text
        gstrPassword = fLogin.txtPassword.Text
        gstrAlias = fLogin.txtDatasource.Text
        gstrTitle = "TsExplorer"
        gstrWSDLLocation = fLogin.txtWSDLLocation.Text
        System.Windows.Forms.Cursor.Current = System.Windows.Forms.Cursors.WaitCursor
        On Error Resume Next
        
        Dim oNetProxyLogin As New NetWebServicesClientProxy.ibm.com.LoginManagerEJBService()
        oNetProxyLogin.Url = gstrURL
        strClientControllerKey = oNetProxyLogin.integrationLogin(gstrUserName, gstrPassword, gstrAlias, "", "")

        oNetHeaderHandler = New NetSoapHeaderHandler.SoapHeaderHandler()

        If Err.Number <> 0 Then
            MsgBox(Err.Description)
            fLogin.LoginSucceeded = False
        End If
        oNetProxyLogin.Dispose()
     
        fMainForm = New frmMain()
        fMainForm.Text = fMainForm.Text & " [WS] "

        fMainForm.Text = fMainForm.Text & " - " & gstrUserName & "@" & gstrAlias
        fMainForm.lblConnect.Text = "//"

        mNode = fMainForm.TreeView1.Nodes.Add(gstrAlias)
        mNode.Tag = "ROOT"

        fMainForm.TreeView1.Sorted = True
        fMainForm.TreeView1.LabelEdit = False

        fMainForm.TreeView1.Sorted = True
        System.Windows.Forms.Cursor.Current = System.Windows.Forms.Cursors.WaitCursor

        LoadViews()

        System.Windows.Forms.Cursor.Current = System.Windows.Forms.Cursors.Default
        System.Windows.Forms.Application.Run(fMainForm)

        Exit Sub

errhandler:

        MsgBox(Err.Description & ": " & Err.Number)


    End Sub
End Module